@@ -1,13 +1,14 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "sumibi" "4.2.0"
+(define-package "sumibi" "5.1.0"
   "Japanese input method powered by ChatGPT API."
   '((emacs          "29.0")
     (popup          "0.5.9")
     (unicode-escape "1.1")
-    (deferred       "0.5.1"))
+    (deferred       "0.5.1")
+    (markdown-mode  "2.0"))
   :url "https://github.com/kiyoka/Sumibi"
-  :commit "47ecde2e815e4540bbb110bee1c0d5c50569f6f8"
-  :revdesc "4.2.0-0-g47ecde2e815e"
+  :commit "581a6d61ecc6d627676f946f9703b0fc74685551"
+  :revdesc "5.1.0-0-g581a6d61ecc6"
   :keywords '("lisp" "ime" "japanese")
   :authors '(("Kiyoka Nishiyama" . "kiyoka@sumibi.org"))
   :maintainers '(("Kiyoka Nishiyama" . "kiyoka@sumibi.org")))
